package system

import (
	"encoding/json"
	"hongze/equity_admin/controllers"
	"hongze/equity_admin/models"
	"hongze/equity_admin/models/system"
	"hongze/equity_admin/utils"
	"time"
)

//系统相关
type SysUserController struct {
	controllers.BaseCommonController
}

// @Title 系统用户登录接口
// @Description 系统用户登录
// @Param	request	body system.LoginReq true "type json string"
// @Success 200 {object} system.LoginResp
// @router /login [post]
func (this *SysUserController) Login() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	var req system.LoginReq
	err := json.Unmarshal(this.Ctx.Input.RequestBody, &req)
	if err != nil {
		br.Msg = "参数解析异常！"
		br.ErrMsg = "参数解析失败，Err:" + err.Error()
		return
	}

	if req.Username == "" {
		br.Msg = "请输入账号"
		return
	}

	if req.Password == "" {
		br.Msg = "请输入密码"
		return
	}

	sysUser, err := system.CheckSysUser(req.Username, req.Password)
	if err != nil {
		if err.Error() == utils.ErrNoRow() {
			br.Msg = "登录失败,账号或密码错误"
			br.ErrMsg = "登录失败，账号或密码错误,Err:" + err.Error()
			br.IsSendEmail = false
			return
		}
		br.IsSendEmail = false
		br.Msg = "登录失败,账号或密码错误"
		br.ErrMsg = "登录失败，Err:" + err.Error()
		return
	}
	if sysUser == nil {
		br.IsSendEmail = false
		br.Msg = "登录失败,账号或密码错误"
		br.ErrMsg = "登录失败，sysUser is nil "
		return
	}
	if sysUser.Enabled == 0 {
		br.Msg = "您的账号已被禁用，如需登录，请联系管理员"
		return
	}
	account := utils.MD5(req.Username)
	token := utils.MD5(req.Username + time.Now().Format(utils.FormatDateTimeUnSpace))
	sysSession := new(system.SysSession)
	sysSession.UserName = req.Username
	sysSession.SysUserId = sysUser.AdminId
	sysSession.ExpiredTime = time.Now().AddDate(0, 0, 90)
	sysSession.CreatedTime = time.Now()
	sysSession.LastUpdatedTime = time.Now()
	sysSession.AccessToken = token
	err = system.AddSysSession(sysSession)
	if err != nil {
		br.ErrMsg = "新增session信息失败，Err:" + err.Error()
		br.Msg = "登录失败"
		return
	}
	resp := new(system.LoginResp)
	resp.Authorization = token
	resp.Authorization = "authorization=" + token + ";account=" + account
	resp.RealName = sysUser.RealName
	resp.AdminName = sysUser.AdminName
	resp.RoleName = sysUser.RoleName

	resp.RoleTypeCode = sysUser.RoleTypeCode

	if sysUser.RoleTypeCode == utils.ROLE_TYPE_CODE_FICC_GROUP {
		resp.RoleTypeCode = utils.ROLE_TYPE_CODE_FICC_SELLER
	}

	if sysUser.RoleTypeCode == utils.ROLE_TYPE_CODE_FICC_DEPARTMENT {
		resp.RoleTypeCode = utils.ROLE_TYPE_CODE_FICC_SELLER
	}

	if sysUser.RoleTypeCode == utils.ROLE_TYPE_CODE_RAI_GROUP {
		resp.RoleTypeCode = utils.ROLE_TYPE_CODE_RAI_SELLER
	}

	if sysUser.RoleTypeCode == utils.ROLE_TYPE_CODE_RAI_DEPARTMENT {
		resp.RoleTypeCode = utils.ROLE_TYPE_CODE_RAI_SELLER
	}

	resp.AdminId = sysUser.AdminId
	var productName string
	productName = "admin"
	resp.ProductName = productName
	resp.Authority = sysUser.Authority
	br.Ret = 200
	br.Success = true
	br.Msg = "登录成功"
	br.Data = resp
}

type SysUserAuthController struct {
	controllers.BaseAuthController
}

// @Title 修改密码
// @Description 修改密码
// @Param	request	body system.ModifyPwdReq true "type json string"
// @Success 200 {object} system.LoginResp
// @router /modify/pwd [post]
func (this *SysUserAuthController) ModifyPwd() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	var req system.ModifyPwdReq
	err := json.Unmarshal(this.Ctx.Input.RequestBody, &req)
	if err != nil {
		br.Msg = "参数解析异常！"
		br.ErrMsg = "参数解析失败，Err:" + err.Error()
		return
	}
	sysUser := this.SysUser
	if sysUser == nil {
		br.Msg = "登录失败,账号或密码错误"
		br.ErrMsg = "登录失败，sysUser is nil "
		return
	}
	if req.OldPwd == "" {
		br.Msg = "原始密码不能为空"
		return
	}

	if req.NewPwd == "" {
		br.Msg = "新密码不能为空"
		return
	}

	if sysUser.Password != req.OldPwd {
		br.Msg = "旧密码错误，请重新输入"
		return
	}
	err = system.ModifyPwd(sysUser.AdminId, req.NewPwd)
	if err != nil {
		br.Msg = "修改失败"
		br.ErrMsg = "修改失败，Err:" + err.Error()
		return
	}

	br.Ret = 200
	br.Success = true
	br.Msg = "修改成功"
}