package data_input

import "rdluck_tools/orm"

type FieldInfo struct {
	TradeName    string `description:"公司或者行业名"`
	SubclassName string `description:"分类名称"`
	FieldName    string `description:"指标名称"`
	FieldCode    string `description:"指标代码"`
	DbName       string `description:"指标数据库名"`
	TableName    string `description:"指标数据表名"`
	Unit         string `description:"指标单位"`
	DateType     string `description:"指标日期类型"`
	DataSource   string `json:"-" description:"指标数据来源"`
	TradeType    string `description:"该指标数据所在分类"`
	ModifyDate   string `description:"待更新日期"`
	Status       int    `description:"状态,1:待更新,2:已更新，3:暂停"`
	StartDate    string `description:"数据开始日期"`
	EndDate      string `description:"数据结束日期"`
}

func GetFieldInfoList(condition string, pars []interface{}) (list []*FieldInfo, err error) {
	o := orm.NewOrm()
	o.Using("data")
	sql := ` SELECT * FROM field_info AS a WHERE 1=1 AND data_source='非标数据' `
	if condition != "" {
		sql += condition
	}
	sql += ` ORDER BY a.status ASC,modify_date DESC `
	_, err = o.Raw(sql, pars).QueryRows(&list)
	return
}

//判断指标数据是否已经更新
func GetDataCount(tradeCode, startDate, endDate string) (count int, err error) {
	o := orm.NewOrm()
	o.Using("data")
	sql := ` SELECT COUNT(1) AS count FROM info_data AS a
			WHERE a.TRADE_CODE=?
			AND a.DT>?
			AND a.DT<=? `
	err = o.Raw(sql, tradeCode, startDate, endDate).QueryRow(&count)
	return
}

func GetFieldInfoByFieldCode(fieldCode string) (item *FieldInfo, err error) {
	o := orm.NewOrm()
	o.Using("data")
	sql := ` SELECT * FROM field_info AS a WHERE 1=1 AND field_code=? AND data_source='非标数据' `
	err = o.Raw(sql).QueryRow(&item)
	return
}

func GetFieldInfoAllList() (list []*FieldInfo, err error) {
	o := orm.NewOrm()
	o.Using("data")
	sql := ` SELECT * FROM field_info AS a WHERE 1=1 AND data_source='非标数据' `
	_, err = o.Raw(sql).QueryRows(&list)
	return
}
