package data_input

import (
	"rdluck_tools/orm"
	"rdluck_tools/paging"
)

type InfoData struct {
	Id         int     `description:"数据主键" orm:"column(id);pk" `
	TradeCode  string  `orm:"column(TRADE_CODE)" description:"指标编码"`
	Dt         string  `orm:"column(DT)" description:"日期"`
	Close      float64 `orm:"column(CLOSE)" description:"值"`
	ModifyTime string  `orm:"column(modify_time)" description:"修改日期"`
}

func AddInfoData(item *InfoData) (err error) {
	o := orm.NewOrm()
	o.Using("data")
	_, err = o.Insert(item)
	return
}

func GetInfoDataList(tradeCode string, startSize, pageSize, sort int) (list []*InfoData, err error) {
	o := orm.NewOrm()
	o.Using("data")
	sql := ` SELECT * FROM info_data WHERE TRADE_CODE=? `
	if sort == 1 || sort == 0 {
		sql += ` ORDER BY DT DESC `
	} else {
		sql += ` ORDER BY DT ASC `
	}
	sql += ` LIMIT ?,? `
	_, err = o.Raw(sql, tradeCode, startSize, pageSize).QueryRows(&list)
	return
}

func GetInfoDataCount(tradeCode string) (count int, err error) {
	o := orm.NewOrm()
	o.Using("data")
	sql := ` SELECT COUNT(1) AS count FROM info_data WHERE TRADE_CODE=? `
	err = o.Raw(sql, tradeCode).QueryRow(&count)
	return
}

type FieldDataListResp struct {
	List   []*InfoData
	Paging *paging.PagingItem `description:"分页数据"`
}

type FieldDataDeleteReq struct {
	Id        int    `description:"数据主键"`
	TradeCode string `orm:"column(TRADE_CODE)" description:"指标编码"`
}

func DeleteFieldData(id int) (err error) {
	o := orm.NewOrm()
	o.Using("data")
	sql := ` DELETE FROM info_data WHERE id=? `
	_, err = o.Raw(sql, id).Exec()
	return
}

type FieldDataSaveReq struct {
	Id        int     `description:"指标数据Id"`
	FieldCode string  `description:"指标代码"`
	Dt        string  `orm:"column(DT)" description:"日期"`
	Close     float64 `orm:"column(CLOSE)" description:"值"`
}

func GetInfoDataCountByDate(tradeCode, date string) (count int, err error) {
	o := orm.NewOrm()
	o.Using("data")
	sql := ` SELECT COUNT(1) AS count FROM info_data WHERE TRADE_CODE=? AND DT=? `
	err = o.Raw(sql, tradeCode, date).QueryRow(&count)
	return
}

func ModifyInfoData(date string, close float64, id int) (err error) {
	o := orm.NewOrm()
	o.Using("data")
	sql := ` UPDATE info_data SET DT=?,CLOSE=?,modify_time=NOW() WHERE id=? `
	_, err = o.Raw(sql, date, close, id).Exec()
	return
}

type SuspendEnableSaveReq struct {
	FieldCode string `description:"指标代码"`
	Status    int    `description:"当前状态:1:待更新,2:已更新，3:暂停"`
}

func GetMaxAndMinDate(fieldCode string) (max_date, min_date string, err error) {
	o := orm.NewOrm()
	o.Using("data")
	sql := ` SELECT MAX(DT) AS max_date,MAX(DT) AS min_date FROM info_data AS a WHERE 1=1 AND TRADE_CODE=? `
	err = o.Raw(sql, fieldCode).QueryRow(&max_date, &min_date)
	return
}
