package data_input

import (
	"hongze/equity_admin/utils"
	"rdluck_tools/orm"
)

type Industry struct {
	IndustryType string `description:"行业分类名称"`
	CompanyTotal int    `description:"公司总数"`
}

func GetAdminIndustryList(roleTypeCode, industryStr string) (list []*Industry, err error) {
	o := orm.NewOrm()
	o.Using("data")

	sql := ``
	if roleTypeCode == utils.ROLE_TYPE_CODE_ADMIN {
		sql = ` SELECT industry_type,COUNT(1) AS company_total FROM trade_info AS a
            INNER JOIN field_info AS b ON a.trade_name=b.trade_name
            WHERE b.data_source='非标数据'
			GROUP BY a.industry_type
			ORDER BY company_total DESC `
		_, err = o.Raw(sql).QueryRows(&list)
		return
	} else {
		sql := `SELECT a.industry_type,COUNT(1) AS company_total FROM trade_info AS a
        INNER JOIN field_info AS b ON a.trade_name=b.trade_name
		WHERE b.data_source='非标数据' 
        AND SUBSTRING_INDEX(a.industry_type,'|',1) IN (` + industryStr + `)
		GROUP BY a.industry_type
		ORDER BY company_total DESC `
		_, err = o.Raw(sql).QueryRows(&list)
		return
	}
}

type IndustryResp struct {
	List []*Industry
}

type IndustrySearch struct {
	IndustryType string `description:"行业分类名称"`
	IsAuth       bool   `description:"true:拥有权限,false:无权限"`
}

type IndustrySearchResp struct {
	List []*IndustrySearch
}

func GetIndustrySearch(keyword string) (list []*IndustrySearch, err error) {
	o := orm.NewOrm()
	o.Using("data")
	sql := ` SELECT a.industry_type FROM trade_info AS a
                INNER JOIN field_info AS b ON a.trade_name=b.trade_name
				WHERE b.data_source='非标数据' 
                AND a.industry_type LIKE '%` + keyword + `%'
				GROUP BY a.industry_type
				ORDER BY a.industry_type ASC `
	_, err = o.Raw(sql).QueryRows(&list)
	return
}

func GetAllIndustrySearch() (list []*IndustrySearch, err error) {
	o := orm.NewOrm()
	o.Using("data")
	sql := ` SELECT a.industry_type FROM trade_info AS a
                INNER JOIN field_info AS b ON a.trade_name=b.trade_name
				WHERE b.data_source='非标数据' 
				GROUP BY a.industry_type
				ORDER BY a.industry_type ASC `
	_, err = o.Raw(sql).QueryRows(&list)
	return
}

type CompanyList struct {
	TradeName      string       `description:"公司或者行业名"`
	IndustryType   string       `description:"行业分类名称"`
	IsAuth         bool         `description:"true:拥有权限,false:无权限"`
	FieldInfoTotal int          `description:"需要更新的指标个数"`
	FieldInfoList  []*FieldInfo `description:"指标列表"`
}

type CompanyListResp struct {
	List []*CompanyList
}

func GetCompanyList(condition string, pars []interface{}) (list []*CompanyList, err error) {
	o := orm.NewOrm()
	o.Using("data")
	sql := ` SELECT a.trade_name,a.industry_type FROM trade_info AS a 
 			INNER JOIN field_info AS b ON a.trade_name=b.trade_name
    		WHERE b.data_source='非标数据' `
	if condition != "" {
		sql += condition
	}
	sql += ` GROUP BY a.trade_name ORDER BY b.status ASC`
	_, err = o.Raw(sql, pars).QueryRows(&list)
	return
}

//修改状态
func ModifyFieldInfoStatus(fieldCode, maxDate, minDate, modifyDate string, status int) (err error) {
	o := orm.NewOrm()
	o.Using("data")
	sql := ` UPDATE field_info SET status=? ,start_date=? ,end_date=?,modify_date=?  WHERE field_code=? `
	_, err = o.Raw(sql, status, minDate, maxDate, modifyDate, fieldCode).Exec()
	return
}
