package system

import (
	"rdluck_tools/orm"
	"time"
)

type SysGroupAddReq struct {
	DepartmentId int    `description:"部门Id"`
	GroupName    string `description:"分组名称,多个用英文逗号隔开"`
}

type SysGroup struct {
	GroupId      int       `orm:"column(group_id);pk" description:"分组ID"`
	DepartmentId int       `description:"部门Id"`
	GroupName    string    `description:"分组名称"`
	CreateTime   time.Time `description:"创建时间"`
}

func GetSysGroupCount(departmentId int, groupName string) (count int, err error) {
	sql := `SELECT COUNT(1) AS count FROM sys_group WHERE department_id=? AND group_name=? `
	o := orm.NewOrm()
	err = o.Raw(sql, departmentId, groupName).QueryRow(&count)
	return
}

func AddSysGroup(item *SysGroup) (lastId int64, err error) {
	o := orm.NewOrm()
	lastId, err = o.Insert(item)
	return
}

type SysGroupEditReq struct {
	GroupId   int    `description:"分组ID"`
	GroupName string `description:"分组名称"`
}

func GetSysGroupById(groupId int) (item *SysGroup, err error) {
	sql := `SELECT * FROM sys_group WHERE group_id=? `
	o := orm.NewOrm()
	err = o.Raw(sql, groupId).QueryRow(&item)
	return
}

func GetSysGroupByName(groupName string) (item *SysGroup, err error) {
	sql := `SELECT * FROM sys_group WHERE group_name=? `
	o := orm.NewOrm()
	err = o.Raw(sql, groupName).QueryRow(&item)
	return
}

func ModifySysGroup(groupName string, groupId int) (err error) {
	o := orm.NewOrm()
	o.Begin()
	defer func() {
		if err != nil {
			o.Rollback()
		} else {
			o.Commit()
		}
	}()
	sql := `UPDATE sys_group SET group_name=? WHERE group_id=? `
	_, err = o.Raw(sql, groupName, groupId).Exec()
	sql = `UPDATE admin SET group_name=? WHERE group_id=? `
	_, err = o.Raw(sql, groupName, groupId).Exec()
	return
}

type SysGroupDeleteReq struct {
	GroupId int `description:"分组ID"`
}

func DeleteSysGroup(groupId int) (err error) {
	sql := `DELETE FROM sys_group WHERE group_id=? `
	o := orm.NewOrm()
	_, err = o.Raw(sql, groupId).Exec()
	return
}

type SysGroupList struct {
	DepartmentId int       `orm:"column(group_id);pk" description:"分组ID"`
	GroupName    string    `json:"DepartmentName" description:"分组名称"`
	CreateTime   time.Time `description:"创建时间"`
}

func GetSysGroupByDepartmentId(departmentId int) (items []*SysGroupList, err error) {
	sql := `SELECT * FROM sys_group WHERE department_id=? `
	o := orm.NewOrm()
	_, err = o.Raw(sql, departmentId).QueryRows(&items)
	return
}

func ClearSysUserGroup(groupId int) (err error) {
	sql := `UPDATE admin SET group_id=0,group_name='' WHERE group_id=? `
	o := orm.NewOrm()
	_, err = o.Raw(sql, groupId).Exec()
	return
}
