package models

import (
	"encoding/json"
	"errors"
	"fmt"
	"hongze/equity_admin/utils"
	"rdluck_tools/http"
	"strings"
	"time"
)

type WxToken struct {
	AccessToken string
	ExpiresIn   int64
	Id          int64
}

func GetWxAccessToken() (accessTokenStr string, err error) {
	accessToken, err := GetWxToken()
	if err != nil {
		return "", err
	}
	if accessToken.AccessToken != "" {
		accessTokenStr = accessToken.AccessToken
	}
	return accessTokenStr, err
}

type WxAccessToken struct {
	AccessToken string `json:"access_token"`
	ExpiresIn   int    `json:"expires_in"`
	Errcode     int
	Errmsg      string
}

func GetWxToken() (item *WxAccessToken, err error) {
	getUrl := "https://api.weixin.qq.com/cgi-bin/token?grant_type=client_credential&appid=" + utils.WxAppId + "&secret=" + utils.WxAppSecret
	result, err := http.Get(getUrl)
	if err != nil {
		utils.FileLog.Info("GetWxToken Err:", err.Error())
		return
	}
	err = json.Unmarshal(result, &item)
	if err != nil {
		fmt.Println("GetWxToken Unmarshal Err:%s", err.Error())
		return
	}
	if item.Errmsg != "" {
		utils.FileLog.Info("GetWxToken fail result:%s", string(result))
	}

	if utils.Re == nil {
		utils.Rc.Put(utils.CACHE_WECHAT_TOKEN, string(result), 110*time.Minute)
	}
	return
}

type WxUsers struct {
	WxBase
	Total int
	Count int
	Data  struct {
		Openid []string
	}
	NextOpenid string
}

//微信接口基础返回数据
type WxBase struct {
	Errcode int
	Errmsg  string
}

func WxUsersGet() (openIdStr string) {
	accessToken, err := GetWxAccessToken()
	if err != nil {
		utils.FileLog.Info("GetWxAccessToken Err:%s", err.Error())
		return
	}
	url := "https://api.weixin.qq.com/cgi-bin/user/get?access_token=" + accessToken
	result, err := http.Get(url)
	if err != nil {
		utils.FileLog.Info("GetUser Err:", err.Error())
		return
	}
	item := new(WxUsers)
	err = json.Unmarshal(result, &item)
	if err != nil {
		fmt.Println("Unmarshal Err:", err.Error())
		return
	}
	if item.Errcode != 0 {
		utils.FileLog.Info("微信接口返回异常 Err：", item.Errmsg)
		return
	}
	err = errors.New(item.Errmsg)

	openIdStr = strings.Join(item.Data.Openid, "','")
	openIdStr = "'" + openIdStr + "'"
	return
}
