package services

import (
	"hongze/equity_admin/utils"
	"strconv"
	"time"
)

func GetDateByFrequency(frequency string) (needUpdateDate string, err error) {
	year, month, _ := time.Now().Date()
	monthInt := int(month)

	switch frequency {
	case "年度":
		needUpdateDate = strconv.Itoa(year) + "-12-31"
		return
	case "半年度":
		if monthInt < 7 {
			needUpdateDate = strconv.Itoa(year) + "-06-30"
		} else {
			needUpdateDate = strconv.Itoa(year) + "-12-31"
		}
	case "季度":
		if monthInt >= 1 && monthInt <= 3 {
			needUpdateDate = strconv.Itoa(year) + "-03-31"
		} else if monthInt >= 4 && monthInt <= 6 {
			needUpdateDate = strconv.Itoa(year) + "-06-30"
		} else if monthInt >= 7 && monthInt <= 9 {
			needUpdateDate = strconv.Itoa(year) + "-09-30"
		} else {
			needUpdateDate = strconv.Itoa(year) + "-12-31"
		}
	case "月度":
		needUpdateDate = GetLastDateOfMonth(time.Now()).Format(utils.FormatDate)
	}
	return
}

//获取传入的时间所在月份的第一天，即某月第一天的0点。如传入time.Now(), 返回当前月份的第一天0点时间。
func GetFirstDateOfMonth(d time.Time) time.Time {
	d = d.AddDate(0, 0, -d.Day()+1)
	return GetZeroTime(d)
}

//获取传入的时间所在月份的最后一天，即某月最后一天的0点。如传入time.Now(), 返回当前月份的最后一天0点时间。
func GetLastDateOfMonth(d time.Time) time.Time {
	return GetFirstDateOfMonth(d).AddDate(0, 1, -1)
}

//获取某一天的0点时间
func GetZeroTime(d time.Time) time.Time {
	return time.Date(d.Year(), d.Month(), d.Day(), 0, 0, 0, 0, d.Location())
}

/*
待更新日期，根据频度计算：

日度  每日更新

月度  每月最后一天

季度   每个季度的最后一天 如一季度3.31  二季度6.30 三季度 9.30  四季度12.31

半年度  6.30   12.31

年度  12.31

未更新：截止更新当天还未添加值则为未更新

已更新：本次已更新和下次更新前一日之间的时间段内状态均为已更新

*/
