package services

import (
	"fmt"
	"hongze/equity_admin/models"
	"hongze/equity_admin/models/data_input"
	"hongze/equity_admin/utils"
	"strconv"
	"strings"
)

//到期消息提醒
func SendMessageMind() {
	var err error
	defer func() {
		if err != nil {
			utils.FileLog.Info("SendMessageMind Err:" + err.Error())
		}
	}()

	fieldInfoList, err := data_input.GetRemindFieldInfo()
	if err != nil {
		return
	}
	//nowStr := time.Now().Format(utils.FormatDate)

	for _, v := range fieldInfoList {
		needModifyDate, err := GetDateByFrequency(v.DateType)
		if err != nil {
			utils.FileLog.Info("GetDateByFrequency:Err %s", err.Error())
		}
		if needModifyDate == "2021-09-30" {
			//判断当日数据是否更新
			count, err := data_input.GetInfoDataCountByDate(v.FieldCode, needModifyDate)
			if err != nil && err.Error() != utils.ErrNoRow() {
				return
			}
			//发布消息通知
			if count <= 0 {
				var industryTypeStr string
				industryTypeArr := strings.Split(v.IndustryType, "|")
				if len(industryTypeArr) > 1 {
					industryTypeStr = industryTypeArr[0]
				}
				fmt.Println(industryTypeStr)
				if industryTypeStr != "" {
					fmt.Println("GetRemindUsers")
					userList, err := data_input.GetRemindUsers(industryTypeStr)
					if err != nil {
						fmt.Println("GetRemindUsers", err.Error())
						return
					}
					fmt.Println("userList len:", len(userList))
					openIdList := make([]*models.OpenIdList, 0)
					if utils.RunMode == "debug" {
						for _, uv := range userList {
							if uv.AdminName == "admin" {
								openId := uv.OpenId
								openIdItem := new(models.OpenIdList)
								openIdItem.OpenId = openId
								openIdList = append(openIdList, openIdItem)
							}
						}
					} else {
						for _, uv := range userList {
							openId := uv.OpenId
							openIdItem := new(models.OpenIdList)
							openIdItem.OpenId = openId
							openIdList = append(openIdList, openIdItem)
						}
					}
					fmt.Println("lenOpenIdList:", len(openIdList))
					if len(openIdList) > 0 {
						first := "数据录入提醒"
						keyword1 := v.TradeName + v.SubclassName + v.FieldName
						keyword2 := needModifyDate
						remark := keyword1 + " 该更新了"
						err = SendWxMsgWithFrequency(first, keyword1, keyword2, remark, openIdList)
						if err != nil {
							utils.FileLog.Info("SendWxMsgWithFrequency Err:" + err.Error())
						}
					}
				}
			}
		}
	}
}

//到期消息提醒(总条数方式提醒)
func SendMessageMindTotal() (err error){
	defer func() {
		if err != nil {
			utils.FileLog.Info("SendMessageMind Err:" + err.Error())
		}
	}()

	userList, err := data_input.GetRemindUsersAll()
	if err != nil {
		fmt.Println("GetRemindUsersAll Err:", err.Error())
		return
	}
	nowStr := "2021-09-30" //time.Now().Format(utils.FormatDate)

	for _, uv := range userList {
		if utils.RunMode == "debug" && uv.AdminName != "admin" {
			continue
		}
		fmt.Println(uv.IndustryType, uv.AdminName)
		industryArr := strings.Split(uv.IndustryType, ",")
		tipsMsg := ""
		var isTips bool
		industryMap := make(map[string]string)
		for _, iv := range industryArr {
			//根据行业获取指标
			fieldList, err := data_input.GetRemindFieldInfoByIndustry(iv)
			if err != nil {
				fmt.Println("GetRemindFieldInfoByIndustry Err:", err.Error())
				return err
			}
			fieldCount := 0
			for _, fv := range fieldList {
				needModifyDate, _ := GetDateByFrequency(fv.DateType)
				if needModifyDate == nowStr {
					count, err := data_input.GetInfoDataCountByDate(fv.FieldCode, needModifyDate)
					if err != nil && err.Error() != utils.ErrNoRow() {
						return err
					}
					if count <= 0 {
						fieldCount++
						isTips = true
					}
				}
				if _, ok := industryMap[fv.IndustryType]; !ok {
					industryMap[fv.IndustryType] = fv.IndustryType
				}
			}
			tipsMsg += " 共计【" + strconv.Itoa(fieldCount) + "】个指标"
		}
		var industryStr string
		for _, mv := range industryMap {
			industryStr += mv + "、"
		}
		industryStr = strings.Trim(industryStr, "、")
		if isTips {
			openIdList := make([]*models.OpenIdList, 0)
			openId := uv.OpenId
			openIdItem := new(models.OpenIdList)
			openIdItem.OpenId = openId
			openIdList = append(openIdList, openIdItem)
			if len(openIdList) > 0 {
				first := "数据录入提醒" + " 待更新"
				keyword1 := "你负责的行业 " + industryStr + tipsMsg + " 待更新"
				keyword2 := nowStr
				remark := "最晚更新时间" + nowStr + " 不要忘记哦"
				err = SendWxMsgWithFrequency(first, keyword1, keyword2, remark, openIdList)
				if err != nil {
					utils.FileLog.Info("SendWxMsgWithFrequency Err:" + err.Error())
				}
			}
		}
	}
	return
}
