package services

import (
	"bytes"
	"encoding/json"
	"fmt"
	"hongze/equity_admin/models"
	"hongze/equity_admin/utils"
	"io/ioutil"
	"net/http"
	"time"
)

func sendTemplateMsg(sendUrl string, sendMap map[string]interface{}, items []*models.OpenIdList) (err error) {
	for _, v := range items {
		sendMap["touser"] = v.OpenId
		data, err := json.Marshal(sendMap)
		if err != nil {
			fmt.Println("SendTemplateMsgOne Marshal Err:", err.Error())
			utils.FileLog.Info("SendTemplateMsgOne Marshal Err:%s", err.Error())
			return err
		}
		err = toSendTemplateMsg(sendUrl, data)
		if err != nil {
			fmt.Println("send err:", err.Error())
			utils.FileLog.Info("ToSendTemplateMsg Err:%s", err.Error())
		}
	}
	return
}

func toSendTemplateMsg(sendUrl string, data []byte) (err error) {
	utils.FileLog.Info("Send:%s", string(data))
	client := http.Client{}
	resp, err := client.Post(sendUrl, "application/json", bytes.NewBuffer(data))
	if err != nil {
		return
	}
	defer resp.Body.Close()

	body, _ := ioutil.ReadAll(resp.Body)
	utils.FileLog.Info("SendResult:%s", string(body))
	var templateResponse SendTemplateResponse
	err = json.Unmarshal(body, &templateResponse)
	if err != nil {
		utils.FileLog.Info("SendResult Unmarshal Err:%s", err.Error())
		return err
	}
	return
}

type SendTemplateResponse struct {
	Errcode int    `json:"errcode"`
	Errmsg  string `json:"errmsg"`
	MsgID   int    `json:"msgid"`
}

func SendWxMsgWithFrequency(first, keyword1, keyword2, remark string, openIdList []*models.OpenIdList) (err error) {
	var msg string
	defer func() {
		if err != nil {
			go utils.SendEmail("发送模版消息失败"+"【"+utils.APPNAME+"】"+time.Now().Format("2006-01-02 15:04:05"), msg+";Err:"+err.Error(), utils.EmailSendToUsers)
			utils.FileLog.Info("发送模版消息失败,Err:%s", err.Error())
		}
		fmt.Println("line 21", err, msg)
	}()
	utils.FileLog.Info("%s", "services SendMsg")
	accessToken:=new(models.WxAccessToken)
	if utils.Re == nil && utils.Rc.IsExist(utils.CACHE_WECHAT_TOKEN) {
		if data, err1 := utils.Rc.RedisBytes(utils.CACHE_WECHAT_TOKEN); err1 == nil {
			err = json.Unmarshal(data, &accessToken)
		}
	}else{
		accessToken, err = models.GetWxToken()
	}
	fmt.Println(err,accessToken)
	if err != nil {
		msg = "GetWxAccessToken Err:" + err.Error()
		return
	}
	if accessToken.AccessToken == "" {
		msg = "accessToken is empty"
		return
	}

	sendUrl := "https://api.weixin.qq.com/cgi-bin/message/template/send?access_token=" + accessToken.AccessToken
	templateId := utils.RemindTemplateId
	//if true{
	sendMap := make(map[string]interface{})
	sendData := make(map[string]interface{})

	sendMap["template_id"] = templateId

	//redirectUrl:="report.hzinsights.com/#/allindex/"+strconv.Itoa(v.ResearchReportId)+"/"+v.ReportType;
	//sendMap["url"]=redirectUrl

	sendData["first"] = map[string]interface{}{"value": first, "color": "#173177"}
	sendData["keyword1"] = map[string]interface{}{"value": keyword1, "color": "#173177"}
	sendData["keyword2"] = map[string]interface{}{"value": keyword2, "color": "#173177"}
	sendData["remark"] = map[string]interface{}{"value": remark, "color": "#173177"}
	sendMap["data"] = sendData
	WxSendTemplateMsg(sendUrl, sendMap, openIdList)
	return
}

func WxSendTemplateMsg(sendUrl string, sendMap map[string]interface{}, items []*models.OpenIdList) (err error) {
	for _, v := range items {
		sendMap["touser"] = v.OpenId
		data, err := json.Marshal(sendMap)
		if err != nil {
			fmt.Println("SendTemplateMsgOne Marshal Err:", err.Error())
			return err
		}
		utils.FileLog.Info("One SendData:%s", string(data))
		err = SendTemplateMsg(sendUrl, data)
		if err != nil {
			fmt.Println("send err:", err.Error())
			return err
		}
	}
	return
}

func SendTemplateMsg(sendUrl string, data []byte) (err error) {
	client := http.Client{}
	resp, err := client.Post(sendUrl, "application/json", bytes.NewBuffer(data))
	if err != nil {
		return
	}
	defer resp.Body.Close()

	body, _ := ioutil.ReadAll(resp.Body)
	utils.FileLog.Info("SendResult:%s", string(body))
	var templateResponse models.SendTemplateResponse
	err = json.Unmarshal(body, &templateResponse)
	if err != nil {
		return err
	}
	return
}
